==> patternfly-java-components-0.3.0.jar: org/patternfly/component/modal/ModalBody.java <==
/*
 *  Copyright 2023 Red Hat
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.patternfly.component.modal;

import org.jboss.elemento.ElementTextMethods;

import elemental2.dom.HTMLElement;

import static org.jboss.elemento.Elements.div;
import static org.patternfly.style.Classes.body;
import static org.patternfly.style.Classes.component;
import static org.patternfly.style.Classes.modalBox;

public class ModalBody extends ModalSubComponent<HTMLElement, ModalBody> implements
        ElementTextMethods<HTMLElement, ModalBody> {

    // ------------------------------------------------------ factory

    public static ModalBody modalBody() {
        return new ModalBody();
    }

    // ------------------------------------------------------ instance

    static final String SUB_COMPONENT_NAME = "mb";

    ModalBody() {
        super(SUB_COMPONENT_NAME, div().css(component(modalBox, body)).element());
    }

    // ------------------------------------------------------ builder

    @Override
    public ModalBody that() {
        return this;
    }
}

==> patternfly-java-components-0.3.1.jar: org/patternfly/component/modal/ModalBody.java <==
/*
 *  Copyright 2023 Red Hat
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.patternfly.component.modal;

import org.jboss.elemento.ElementTextMethods;

import elemental2.dom.HTMLElement;

import static org.jboss.elemento.Elements.div;
import static org.patternfly.style.Classes.body;
import static org.patternfly.style.Classes.component;
import static org.patternfly.style.Classes.modalBox;

public class ModalBody extends ModalSubComponent<HTMLElement, ModalBody> implements
        ElementTextMethods<HTMLElement, ModalBody> {

    // ------------------------------------------------------ factory

    public static ModalBody modalBody() {
        return new ModalBody();
    }

    // ------------------------------------------------------ instance

    public static final String SUB_COMPONENT_NAME = "mb";

    ModalBody() {
        super(SUB_COMPONENT_NAME, div().css(component(modalBox, body)).element());
    }

    // ------------------------------------------------------ builder

    @Override
    public ModalBody that() {
        return this;
    }
}
